@@ -1,17 +1,21 @@
 """Internally used rule classes."""
+from __future__ import annotations
+
+import inspect
 import logging
-from typing import TYPE_CHECKING, Any, Dict, List, Union
+from pathlib import Path
+from typing import TYPE_CHECKING, Any
+
+from ansiblelint.constants import RULE_DOC_URL
 
 if TYPE_CHECKING:
-    from typing import Optional
-
-    from ansiblelint.constants import odict
     from ansiblelint.errors import MatchError
     from ansiblelint.file_utils import Lintable
+    from ansiblelint.rules import RulesCollection
 
 _logger = logging.getLogger(__name__)
 LOAD_FAILURE_MD = """\
-## load-failure
+# load-failure
 
 Linter failed to process a YAML file, probably because it is either:
 
@@ -32,21 +36,51 @@ class BaseRule:
     """Root class used by Rules."""
 
     id: str = ""
-    tags: List[str] = []
+    tags: list[str] = []
     description: str = ""
-    help: str = ""  # markdown help (automatically loaded from `<rule>.md`)
     version_added: str = ""
     severity: str = ""
     link: str = ""
     has_dynamic_tags: bool = False
     needs_raw_task: bool = False
+    # We use _order to sort rules and to ensure that some run before others,
+    # _order 0 for internal rules
+    # _order 1 for rules that check that data can be loaded
+    # _order 5 implicit for normal rules
+    _order: int = 5
+    _help: str | None = None
+    # Added when a rule is registered into a collection, gives access to options
+    _collection: RulesCollection | None = None
+
+    @property
+    def help(self) -> str:
+        """Return a help markdown string for the rule."""
+        if self._help is None:
+            self._help = ""
+            md_file = (
+                Path(inspect.getfile(self.__class__)).parent
+                / f"{self.id.replace('-', '_')}.md"
+            )
+            if md_file.exists():
+                self._help = md_file.read_text(encoding="utf-8")
+        return self._help
+
+    @property
+    def url(self) -> str:
+        """Return rule documentation url."""
+        url = self.link
+        if not url:
+            url = RULE_DOC_URL
+            if self.id:
+                url += self.id + "/"
+        return url
 
     @property
     def shortdesc(self) -> str:
         """Return the short description of the rule, basically the docstring."""
         return self.__doc__ or ""
 
-    def getmatches(self, file: "Lintable") -> List["MatchError"]:
+    def getmatches(self, file: Lintable) -> list[MatchError]:
         """Return all matches while ignoring exceptions."""
         matches = []
         if not file.path.is_dir():
@@ -54,23 +88,24 @@ class BaseRule:
                 try:
                     matches.extend(method(file))
                 except Exception as exc:  # pylint: disable=broad-except
-                    _logger.debug(
-                        "Ignored exception from %s.%s: %s",
+                    _logger.warning(
+                        "Ignored exception from %s.%s while processing %s: %s",
                         self.__class__.__name__,
                         method,
+                        str(file),
                         exc,
                     )
         else:
             matches.extend(self.matchdir(file))
         return matches
 
-    def matchlines(self, file: "Lintable") -> List["MatchError"]:
+    def matchlines(self, file: Lintable) -> list[MatchError]:
         """Return matches found for a specific line."""
         return []
 
     def matchtask(
-        self, task: Dict[str, Any], file: "Optional[Lintable]" = None
-    ) -> Union[bool, str]:
+        self, task: dict[str, Any], file: Lintable | None = None
+    ) -> bool | str | MatchError | list[MatchError]:
         """Confirm if current rule is matching a specific task.
 
         If ``needs_raw_task`` (a class level attribute) is ``True``, then
@@ -79,21 +114,19 @@ class BaseRule:
         """
         return False
 
-    def matchtasks(self, file: "Lintable") -> List["MatchError"]:
+    def matchtasks(self, file: Lintable) -> list[MatchError]:
         """Return matches for a tasks file."""
         return []
 
-    def matchyaml(self, file: "Lintable") -> List["MatchError"]:
+    def matchyaml(self, file: Lintable) -> list[MatchError]:
         """Return matches found for a specific YAML text."""
         return []
 
-    def matchplay(
-        self, file: "Lintable", data: "odict[str, Any]"
-    ) -> List["MatchError"]:
+    def matchplay(self, file: Lintable, data: dict[str, Any]) -> list[MatchError]:
         """Return matches found for a specific playbook."""
         return []
 
-    def matchdir(self, lintable: "Lintable") -> List["MatchError"]:
+    def matchdir(self, lintable: Lintable) -> list[MatchError]:
         """Return matches for lintable folders."""
         return []
 
@@ -101,13 +134,17 @@ class BaseRule:
         """Return a verbose representation of the rule."""
         return self.id + ": " + self.shortdesc + "\n  " + self.description
 
-    def match(self, line: str) -> Union[bool, str]:
+    def match(self, line: str) -> bool | str:
         """Confirm if current rule matches the given string."""
         return False
 
-    def __lt__(self, other: "BaseRule") -> bool:
+    def __lt__(self, other: BaseRule) -> bool:
         """Enable us to sort rules by their id."""
-        return self.id < other.id
+        return (self._order, self.id) < (other._order, other.id)
+
+    def __repr__(self) -> str:
+        """Return a AnsibleLintRule instance representation."""
+        return self.id + ": " + self.shortdesc
 
 
 # pylint: enable=unused-argument
@@ -117,15 +154,10 @@ class RuntimeErrorRule(BaseRule):
     """Unexpected internal error."""
 
     id = "internal-error"
-    description = (
-        "This error can be caused by internal bugs but also by "
-        "custom rules. Instead of just stopping linter we generate the errors and "
-        "continue processing. This allows users to add this rule to their warn list until "
-        "the root cause is fixed."
-    )
     severity = "VERY_HIGH"
     tags = ["core"]
     version_added = "v5.0.0"
+    _order = 0
 
 
 class AnsibleParserErrorRule(BaseRule):
@@ -136,6 +168,7 @@ class AnsibleParserErrorRule(BaseRule):
     severity = "VERY_HIGH"
     tags = ["core"]
     version_added = "v5.0.0"
+    _order = 0
 
 
 class LoadingFailureRule(BaseRule):
@@ -147,3 +180,15 @@ class LoadingFailureRule(BaseRule):
     tags = ["core", "unskippable"]
     version_added = "v4.3.0"
     help = LOAD_FAILURE_MD
+    _order = 0
+
+
+class WarningRule(BaseRule):
+    """Other warnings detected during run."""
+
+    id = "warning"
+    severity = "LOW"
+    # should remain experimental as that would keep it warning only
+    tags = ["core", "experimental"]
+    version_added = "v6.8.0"
+    _order = 0
