@@ -59,12 +59,53 @@ def normpath(path: str | BasePathLike) -> str:
     # conversion to string in order to allow receiving non string objects
     relpath = os.path.relpath(str(path))
     path_absolute = os.path.abspath(str(path))
+    if path_absolute.startswith(os.getcwd()):
+        return relpath
+    if path_absolute.startswith(os.path.expanduser("~")):
+        return path_absolute.replace(os.path.expanduser("~"), "~")
     # we avoid returning relative paths that end-up at root level
     if path_absolute in relpath:
         return path_absolute
+    if relpath.startswith("../"):
+        return path_absolute
     return relpath
 
 
+# That is needed for compatibility with py38, later was added to Path class
+def is_relative_to(path: Path, *other: Any) -> bool:
+    """Return True if the path is relative to another path or False."""
+    try:
+        path.resolve().absolute().relative_to(*other)
+        return True
+    except ValueError:
+        return False
+
+
+def normpath_path(path: str | BasePathLike) -> Path:
+    """Normalize a path in order to provide a more consistent output.
+
+    - Any symlinks are resolved.
+    - Any paths outside the CWD are resolved to their absolute path.
+    - Any absolute path within current user home directory is compressed to
+      make use of '~', so it is easier to read and more portable.
+    """
+    if not isinstance(path, Path):
+        path = Path(path)
+
+    is_relative = is_relative_to(path, path.cwd())
+    path = path.resolve()
+    if is_relative:
+        path = path.relative_to(path.cwd())
+
+    # Compress any absolute path within current user home directory
+    if path.is_absolute():
+        home = Path.home()
+        if is_relative_to(path, home):
+            path = Path("~") / path.relative_to(home)
+
+    return path
+
+
 @contextmanager
 def cwd(path: str | BasePathLike) -> Iterator[None]:
     """Context manager for temporary changing current working directory."""
@@ -133,6 +174,8 @@ class Lintable:
 
     Providing file content when creating the object allow creation of in-memory
     instances that do not need files to be present on disk.
+
+    When symlinks are given, they will always be resolved to their target.
     """
 
     def __init__(
@@ -142,8 +185,6 @@ class Lintable:
         kind: FileType | None = None,
     ):
         """Create a Lintable instance."""
-        # Filename is effective file on disk, for stdin is a namedtempfile
-        self.filename: str = str(name)
         self.dir: str = ""
         self.kind: FileType | None = None
         self.stop_processing = False  # Set to stop other rules from running
@@ -151,11 +192,16 @@ class Lintable:
         self.line_skips: dict[int, set[str]] = defaultdict(set)
 
         if isinstance(name, str):
-            self.name = normpath(name)
-            self.path = Path(self.name)
-        else:
-            self.name = str(name)
-            self.path = name
+            name = Path(name)
+        is_relative = is_relative_to(name, str(name.cwd()))
+        name = name.resolve()
+        if is_relative:
+            name = name.relative_to(name.cwd())
+        name = normpath_path(name)
+        self.path = name
+        # Filename is effective file on disk, for stdin is a namedtempfile
+        self.name = self.filename = str(name)
+
         self._content = self._original_content = content
         self.updated = False
 
@@ -166,7 +212,7 @@ class Lintable:
             role = self.path
             while role.parent.name != "roles" and role.name:
                 role = role.parent
-            if role.exists:
+            if role.exists():
                 self.role = role.name
 
         if str(self.path) in ["/dev/stdin", "-"]:
@@ -191,7 +237,7 @@ class Lintable:
 
         # determine base file kind (yaml, xml, ini, ...)
         self.base_kind = kind_from_path(self.path, base=True)
-        self.abspath = self.path.absolute()
+        self.abspath = self.path.expanduser().absolute()
 
     def __getitem__(self, key: Any) -> Any:
         """Provide compatibility subscriptable support."""
@@ -211,7 +257,7 @@ class Lintable:
     def _populate_content_cache_from_disk(self) -> None:
         # Can raise UnicodeDecodeError
         try:
-            self._content = self.path.resolve().read_text(encoding="utf-8")
+            self._content = self.path.expanduser().resolve().read_text(encoding="utf-8")
         except FileNotFoundError as ex:
             if vars(options).get("progressive"):
                 self._content = ""
@@ -273,7 +319,9 @@ class Lintable:
         if not force and not self.updated:
             # No changes to write.
             return
-        self.path.resolve().write_text(self._content or "", encoding="utf-8")
+        self.path.expanduser().resolve().write_text(
+            self._content or "", encoding="utf-8"
+        )
 
     def __hash__(self) -> int:
         """Return a hash value of the lintables."""
@@ -312,7 +360,11 @@ class Lintable:
 
 # pylint: disable=redefined-outer-name
 def discover_lintables(options: Namespace) -> dict[str, Any]:
-    """Find all files that we know how to lint."""
+    """Find all files that we know how to lint.
+
+    Return format is normalized, relative for stuff below cwd, ~/ for content
+    under current user and absolute for everything else.
+    """
     # git is preferred as it also considers .gitignore
     git_command_present = [
         "git",
@@ -371,10 +423,15 @@ def strip_dotslash_prefix(fname: str) -> str:
 def guess_project_dir(config_file: str | None) -> str:
     """Return detected project dir or current working directory."""
     path = None
-    if config_file is not None:
+    if config_file is not None and config_file != "/dev/null":
         target = pathlib.Path(config_file)
         if target.exists():
-            path = str(target.parent.absolute())
+            # for config inside .config, we return the parent dir as project dir
+            cfg_path = target.parent
+            if cfg_path.parts[-1] == ".config":
+                path = str(cfg_path.parent.absolute())
+            else:
+                path = str(cfg_path.absolute())
 
     if path is None:
         try:
