@@ -53,7 +53,7 @@ def fixture_bracketsmatchtestfile() -> Lintable:
 def test_load_collection_from_directory(test_rules_collection: RulesCollection) -> None:
     """Test that custom rules extend the default ones."""
     # two detected rules plus the internal ones
-    assert len(test_rules_collection) == 6
+    assert len(test_rules_collection) == 7
 
 
 def test_run_collection(
@@ -152,9 +152,9 @@ def test_rich_rule_listing() -> None:
 def test_rules_id_format() -> None:
     """Assure all our rules have consistent format."""
     rule_id_re = re.compile("^[a-z-]{4,30}$")
-    options.enable_list = ["no-same-owner", "no-log-password", "no-same-owner"]
+    # options.enable_list = ["no-same-owner", "no-log-password", "no-same-owner"]
     rules = RulesCollection(
-        [os.path.abspath("./src/ansiblelint/rules")], options=options
+        [os.path.abspath("./src/ansiblelint/rules")], options=options, conditional=False
     )
     keys: set[str] = set()
     for rule in rules:
@@ -166,5 +166,5 @@ def test_rules_id_format() -> None:
             rule.help != "" or rule.description or rule.__doc__
         ), f"Rule {rule.id} must have at least one of:  .help, .description, .__doc__"
     assert "yaml" in keys, "yaml rule is missing"
-    assert len(rules) == 41  # update this number when adding new rules!
-    assert len(keys) == 41, "Duplicate rule ids?"
+    assert len(rules) == 48  # update this number when adding new rules!
+    assert len(keys) == len(rules), "Duplicate rule ids?"
