@@ -333,85 +333,85 @@ def fixture_ruamel_data(lintable: Lintable) -> CommentedMap | CommentedSeq:
             id="1_play_playbook-line_after_eof",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             1,
             [],
             id="4_play_playbook-line_before_play_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             2,
             [0],
             id="4_play_playbook-first_line_in_play_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             5,
             [0],
             id="4_play_playbook-middle_line_in_play_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             9,
             [0],
             id="4_play_playbook-last_line_in_play_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             10,
             [1],
             id="4_play_playbook-first_line_in_play_2",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             14,
             [1],
             id="4_play_playbook-middle_line_in_play_2",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             18,
             [1],
             id="4_play_playbook-last_line_in_play_2",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             19,
             [2],
             id="4_play_playbook-first_line_in_play_3",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             23,
             [2],
             id="4_play_playbook-middle_line_in_play_3",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             27,
             [2],
             id="4_play_playbook-last_line_in_play_3",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             28,
             [3],
             id="4_play_playbook-first_line_in_play_4",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             31,
             [3],
             id="4_play_playbook-middle_line_in_play_4",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             35,
             [3],
             id="4_play_playbook-last_line_in_play_4",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             100,
             [3],
             id="4_play_playbook-line_after_eof",
@@ -552,109 +552,109 @@ def test_get_path_to_play(
             id="1_task_playbook-line_after_eof_without_anything_after_task",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             1,
             [],
             id="4_play_playbook-play_1_line_before_tasks",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             7,
             [0, "tasks", 0],
             id="4_play_playbook-play_1_first_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             9,
             [0, "tasks", 0],
             id="4_play_playbook-play_1_last_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             10,
             [],
             id="4_play_playbook-play_2_line_before_tasks",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             12,
             [],
             id="4_play_playbook-play_2_line_before_tasks",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             13,
             [1, "tasks", 0],
             id="4_play_playbook-play_2_first_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             18,
             [1, "tasks", 0],
             id="4_play_playbook-play_2_middle_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             18,
             [1, "tasks", 0],
             id="4_play_playbook-play_2_last_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             19,
             [],
             id="4_play_playbook-play_3_line_before_tasks",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             22,
             [],
             id="4_play_playbook-play_3_line_before_tasks",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             23,
             [2, "tasks", 0],
             id="4_play_playbook-play_3_first_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             25,
             [2, "tasks", 0],
             id="4_play_playbook-play_3_middle_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             27,
             [2, "tasks", 0],
             id="4_play_playbook-play_3_last_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             28,
             [],
             id="4_play_playbook-play_4_line_before_tasks",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             31,
             [],
             id="4_play_playbook-play_4_line_before_tasks",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             32,
             [3, "tasks", 0],
             id="4_play_playbook-play_4_first_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             33,
             [3, "tasks", 0],
             id="4_play_playbook-play_4_middle_line_task_1",
         ),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             35,
             [3, "tasks", 0],
             id="4_play_playbook-play_4_last_line_task_1",
@@ -701,7 +701,7 @@ def test_get_path_to_play(
         pytest.param(
             "examples/playbooks/blockincludes.yml",
             14,
-            [0, "tasks", 0, "block", 1, "block", 0, "block", 1, "block", 0],
+            [0, "tasks", 0, "block", 1, "block", 0],
             id="playbook-deeply_nested_task",
         ),
         pytest.param(
@@ -850,7 +850,7 @@ def test_get_path_to_task(
     (
         pytest.param("examples/playbooks/become.yml", 0, id="1_play_playbook"),
         pytest.param(
-            "examples/playbooks/become-user-without-become-success.yml",
+            "examples/playbooks/rule-partial-become-without-become-pass.yml",
             0,
             id="4_play_playbook",
         ),
@@ -884,3 +884,23 @@ def test_get_path_to_task_raises_value_error_for_bad_line_number(
         ValueError, match=f"expected line_number >= 1, got {line_number}"
     ):
         ansiblelint.yaml_utils.get_path_to_task(lintable, line_number, ruamel_data)
+
+
+@pytest.mark.parametrize(
+    ("before", "after"),
+    (
+        pytest.param(None, None, id="1"),
+        pytest.param(1, 1, id="2"),
+        pytest.param({}, {}, id="3"),
+        pytest.param({"__file__": 1}, {}, id="simple"),
+        pytest.param({"foo": {"__file__": 1}}, {"foo": {}}, id="nested"),
+        pytest.param([{"foo": {"__file__": 1}}], [{"foo": {}}], id="nested-in-lint"),
+        pytest.param({"foo": [{"__file__": 1}]}, {"foo": [{}]}, id="nested-in-lint"),
+    ),
+)
+def test_deannotate(
+    before: Any,
+    after: Any,
+) -> None:
+    """Ensure deannotate works as intended."""
+    assert ansiblelint.yaml_utils.deannotate(before) == after
